CREATE TABLE `blacklist_ip` (
  `id` int(11) NOT NULL auto_increment,
  `ip` varchar(15) NOT NULL,
  `hits` int(11) NOT NULL default '0',
  PRIMARY KEY  (`id`),
  KEY `ip` (`ip`)
) ;

CREATE TABLE `blacklist_word` (
  `id` int(11) NOT NULL auto_increment,
  `word` varchar(250) NOT NULL,
  `hits` int(11) NOT NULL default '0',
  PRIMARY KEY  (`id`),
  KEY `word` (`word`)
) ;

CREATE TABLE `nopaste` (
  `id` int(11) NOT NULL auto_increment,
  `name` varchar(100) NOT NULL default '',
  `description` text NOT NULL,
  `code` mediumtext,
  `language` text NOT NULL,
  `time` int(15) NOT NULL default '0',
  `ip` varchar(20) NOT NULL,
  `expires` int(11) NOT NULL,
  PRIMARY KEY  (`id`),
  KEY `time` (`time`),
  KEY `expires` (`expires`)
) ;

CREATE TABLE `settings` (
  `username` VARCHAR(100) NOT NULL default 'admin',
  `password` VARCHAR(100) NOT NULL,
  `session` VARCHAR(100) NOT NULL,
  `expires` int(15) NOT NULL default '0',
  `cleanup` int(1) NOT NULL default '1',
  `title` VARCHAR(150) NOT NULL default 'Perl NoPaste Service',
  `style` VARCHAR(20) NOT NULL default 'default',
  `language` VARCHAR(2)  NOT NULL default 'en'
) ;

